@@ -129,12 +129,14 @@ Dat_EBcoBART <- function(X,CoData){
 #' placed Same as in dbarts. Defaults to 0.75. If EB_sigma is TRUE,
 #' this parameter will be fixed, only sigdf and sigest will be updated.
 #'
-#' @return A list object with the estimated variable weights,
-#' i.e the probabilities #' that variables are selected in the splitting rules.
+#' @return An object with the estimated variable weights,
+#' i.e the probabilities that variables are selected in the splitting rules.
 #' Additionally, the final co-data model is returned. If EB is set to TRUE,
 #' estimates of k and/or alpha and/or (sigdf, sigest) are also returned.
+#' The returned object is of class S3 for which print() and summary() are
+#' available
 #' The prior parameter estimates can then be used in your favorite BART R
-#' package that supports #' manually setting the splitting variable
+#' package that supports manually setting the splitting variable
 #' probability vector (dbarts and BARTMachine).
 #' @export
 #'
@@ -273,8 +275,6 @@ EBcoBART <- function(Y,X, model,
   if(!all(Prob_Init > 0 & Prob_Init < 1)) {
     stop("All prior splitting probabilities in Prob_Init
          should be between 0 and 1.")}
-  if(base::sum(Prob_Init) != 1) {stop("Sum of Prob_Init should equal 1.")}
-
 
   if(nchain < 3) {stop("Use at least 3 independent chains")}
   if(!all(c(alpha, beta, k, nchain, ndpost, nskip, nIter, keepevery, ntree) > 0)) {
